@@ -4,6 +4,7 @@ import requests
 from requests.exceptions import HTTPError
 
 from apigee import APIGEE_ADMIN_API_URL, auth, console
+from apigee.references.serializer import ReferencesSerializer
 
 LIST_ALL_REFERENCES_PATH = (
     '{api_url}/v1/organizations/{org_name}/environments/{environment}/references'
@@ -22,25 +23,6 @@ UPDATE_REFERENCE_PATH = (
 )
 
 
-class ReferencesSerializer:
-    def serialize_details(self, references, format, prefix=None):
-        resp = references
-        if format == 'text':
-            return references.text
-        references = references.json()
-        if prefix:
-            references = [
-                reference for reference in references if reference.startswith(prefix)
-            ]
-        if format == 'json':
-            return json.dumps(references)
-        elif format == 'table':
-            pass
-        elif format == 'dict':
-            return references
-        return resp
-
-
 class References:
     def __init__(self, auth, org_name, ref_name):
         self._auth = auth
